# Touch-Reaktion

Das `touch_response` Plug-in erlaubt es Ihnen mit Touch-Reaktionen (oder Mausklicks) auf eine einfache Weise zu arbeiten, in dem der Display in Reihen und Spalten unterteilt wird. Jede Reaktion wird als eine einzelne Nummer kodiert. Diese Nummer korrespondiert zu der Position auf dem Display, beginnend von links nach rechts und oben nach unten. Zum Beispiel, falls Sie 2 Spalten und 3 Reihen eingestellt haben, wird der Display in folgende Reaktionsbereiche eingeteilt:

	1	2
	3	4
	5	6

Ebenso wird ihr Display in folgender Weise horizontal geteilt, wenn Sie 4 Spalten und 1 Reihe wählen:

	1	2	3	4
